## Repository regarding the thorondor package
This repository is the parent folder of the thorondor package, it contains the main program, meant to be imported via `pip install thorondor`.
There is also an example notebook in the example folder.

# How to use from this website:

## Download the package

### Using the zip file
* Click on code (the green button above)
* Click on download zip
* De-zip the `thorondor-main.zip` folder
* Open the folder with your terminal
* Move to the folder where the script `setup.py` is.

### Using git
* Open a folder with your terminal
* Type `git clone https://github.com/DSimonne/thorondor.git`
* Move to the folder where the script `setup.py` is.

## Install the package
* You can type `pip install .`
* If that does not work you can try `python3 setup.py install`

# Test and Example
A test of the program can be done on google colabs, by using the notebook in https://github.com/DSimonne/thorondor/tree/main/thorondor/Example

If you want to test on your own environment,, this notebook is automatically installed along with the package.

# Future work:
* Try to make a better use of voila packagen it works so far but not crazy, maybe just for plotting in big window
* Better import data tool
